@@ -1,5 +1,6 @@
+from typing import Union, Awaitable
+
 from tonclient.module import TonModule
-from tonclient.decorators import result_as
 from tonclient.types import KeyPair, ParamsOfFactorize, ResultOfFactorize, \
     ParamsOfModularPower, ResultOfModularPower, ParamsOfTonCrc16, \
     ResultOfTonCrc16, ParamsOfGenerateRandomBytes, \
@@ -33,30 +34,36 @@ from tonclient.types import KeyPair, ParamsOfFactorize, ResultOfFactorize, \
 class TonCrypto(TonModule):
     """ Free TON crypto SDK API implementation """
 
-    @result_as(classname=ResultOfHash)
-    def sha256(self, params: ParamsOfHash) -> ResultOfHash:
+    def sha256(
+            self, params: ParamsOfHash
+    ) -> Union[ResultOfHash, Awaitable[ResultOfHash]]:
         """
         Calculates SHA256 hash of the specified data
 
         :param params: See `types.ParamsOfHash`
         :return: See `types.ResultOfHash`
         """
-        return self.request(method='crypto.sha256', **params.dict)
+        response = self.request(method='crypto.sha256', **params.dict)
+        return self.response(classname=ResultOfHash, response=response)
 
-    @result_as(classname=ResultOfHash)
-    def sha512(self, params: ParamsOfHash) -> ResultOfHash:
+    def sha512(
+            self, params: ParamsOfHash
+    ) -> Union[ResultOfHash, Awaitable[ResultOfHash]]:
         """
         Calculates SHA512 hash of the specified data
 
         :param params: See `types.ParamsOfHash`
         :return: See `types.ResultOfHash`
         """
-        return self.request(method='crypto.sha512', **params.dict)
+        response = self.request(method='crypto.sha512', **params.dict)
+        return self.response(classname=ResultOfHash, response=response)
 
-    @result_as(classname=ResultOfHDKeyXPrvFromMnemonic)
     def hdkey_xprv_from_mnemonic(
             self, params: ParamsOfHDKeyXPrvFromMnemonic
-    ) -> ResultOfHDKeyXPrvFromMnemonic:
+    ) -> Union[
+        ResultOfHDKeyXPrvFromMnemonic,
+        Awaitable[ResultOfHDKeyXPrvFromMnemonic]
+    ]:
         """
         Generates an extended master private key that will be the root for all
         the derived keys
@@ -64,39 +71,51 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfHDKeyXPrvFromMnemonic`
         :return: See `types.ResultOfHDKeyXPrvFromMnemonic`
         """
-        return self.request(
+        response = self.request(
             method='crypto.hdkey_xprv_from_mnemonic', **params.dict)
+        return self.response(
+            classname=ResultOfHDKeyXPrvFromMnemonic, response=response)
 
-    @result_as(classname=ResultOfHDKeySecretFromXPrv)
     def hdkey_secret_from_xprv(
             self, params: ParamsOfHDKeySecretFromXPrv
-    ) -> ResultOfHDKeySecretFromXPrv:
+    ) -> Union[
+        ResultOfHDKeySecretFromXPrv,
+        Awaitable[ResultOfHDKeySecretFromXPrv]
+    ]:
         """
         Extracts the private key from the serialized extended private key
 
         :param params: See `types.ParamsOfHDKeySecretFromXPrv`
         :return: See `types.ResultOfHDKeySecretFromXPrv`
         """
-        return self.request(
+        response = self.request(
             method='crypto.hdkey_secret_from_xprv', **params.dict)
+        return self.response(
+            classname=ResultOfHDKeySecretFromXPrv, response=response)
 
-    @result_as(classname=ResultOfHDKeyPublicFromXPrv)
     def hdkey_public_from_xprv(
             self, params: ParamsOfHDKeyPublicFromXPrv
-    ) -> ResultOfHDKeyPublicFromXPrv:
+    ) -> Union[
+        ResultOfHDKeyPublicFromXPrv,
+        Awaitable[ResultOfHDKeyPublicFromXPrv]
+    ]:
         """
         Extracts the public key from the serialized extended private key
 
         :param params: See `types.ParamsOfHDKeyPublicFromXPrv`
         :return: See `types.ResultOfHDKeyPublicFromXPrv`
         """
-        return self.request(
+        response = self.request(
             method='crypto.hdkey_public_from_xprv', **params.dict)
+        return self.response(
+            classname=ResultOfHDKeyPublicFromXPrv, response=response)
 
-    @result_as(classname=ResultOfHDKeyDeriveFromXPrv)
     def hdkey_derive_from_xprv(
             self, params: ParamsOfHDKeyDeriveFromXPrv
-    ) -> ResultOfHDKeyDeriveFromXPrv:
+    ) -> Union[
+        ResultOfHDKeyDeriveFromXPrv,
+        Awaitable[ResultOfHDKeyDeriveFromXPrv]
+    ]:
         """
         Returns extended private key derived from the specified extended
         private key and child index
@@ -104,58 +123,71 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfHDKeyDeriveFromXPrv`
         :return: See `types.ResultOfHDKeyDeriveFromXPrv`
         """
-        return self.request(
+        response = self.request(
             method='crypto.hdkey_derive_from_xprv', **params.dict)
+        return self.response(
+            classname=ResultOfHDKeyDeriveFromXPrv, response=response)
 
-    @result_as(classname=ResultOfHDKeyDeriveFromXPrvPath)
     def hdkey_derive_from_xprv_path(
             self, params: ParamsOfHDKeyDeriveFromXPrvPath
-    ) -> ResultOfHDKeyDeriveFromXPrvPath:
+    ) -> Union[
+        ResultOfHDKeyDeriveFromXPrvPath,
+        Awaitable[ResultOfHDKeyDeriveFromXPrvPath]
+    ]:
         """
         Derives the extended private key from the specified key and path
 
         :param params: See `types.ParamsOfHDKeyDeriveFromXPrvPath`
         :return: See `types.ResultOfHDKeyDeriveFromXPrvPath`
         """
-        return self.request(
+        response = self.request(
             method='crypto.hdkey_derive_from_xprv_path', **params.dict)
+        return self.response(
+            classname=ResultOfHDKeyDeriveFromXPrvPath, response=response)
 
-    @result_as(classname=ResultOfConvertPublicKeyToTonSafeFormat)
     def convert_public_key_to_ton_safe_format(
             self, params: ParamsOfConvertPublicKeyToTonSafeFormat
-    ) -> ResultOfConvertPublicKeyToTonSafeFormat:
+    ) -> Union[
+        ResultOfConvertPublicKeyToTonSafeFormat,
+        Awaitable[ResultOfConvertPublicKeyToTonSafeFormat]
+    ]:
         """
         Converts public key to ton safe_format
 
         :param params: See `types.ParamsOfConvertPublicKeyToTonSafeFormat`
         :return: See `types.ResultOfConvertPublicKeyToTonSafeFormat`
         """
-        return self.request(
+        response = self.request(
             method='crypto.convert_public_key_to_ton_safe_format',
             **params.dict)
+        return self.response(
+            classname=ResultOfConvertPublicKeyToTonSafeFormat,
+            response=response)
 
-    @result_as(classname=KeyPair)
-    def generate_random_sign_keys(self) -> KeyPair:
+    def generate_random_sign_keys(self) -> Union[KeyPair, Awaitable[KeyPair]]:
         """
         Generates random ed25519 key pair
 
         :return: See `types.KeyPair`
         """
-        return self.request(method='crypto.generate_random_sign_keys')
+        response = self.request(method='crypto.generate_random_sign_keys')
+        return self.response(classname=KeyPair, response=response)
 
-    @result_as(classname=ResultOfSign)
-    def sign(self, params: ParamsOfSign) -> ResultOfSign:
+    def sign(
+            self, params: ParamsOfSign
+    ) -> Union[ResultOfSign, Awaitable[ResultOfSign]]:
         """
         Signs a data using the provided keys
 
         :param params: See `types.ParamsOfSign`
         :return: See `types.ResultOfSign`
         """
-        return self.request(method='crypto.sign', **params.dict)
+        response = self.request(method='crypto.sign', **params.dict)
+        return self.response(classname=ResultOfSign, response=response)
 
-    @result_as(classname=ResultOfVerifySignature)
     def verify_signature(
-            self, params: ParamsOfVerifySignature) -> ResultOfVerifySignature:
+            self, params: ParamsOfVerifySignature
+    ) -> Union[ResultOfVerifySignature, Awaitable[ResultOfVerifySignature]]:
         """
         Verifies signed data using the provided public key.
         Raises error if verification is failed
@@ -163,11 +195,14 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfVerifySignature`
         :return: See `types.ResultOfVerifySignature`
         """
-        return self.request(method='crypto.verify_signature', **params.dict)
+        response = self.request(
+            method='crypto.verify_signature', **params.dict)
+        return self.response(
+            classname=ResultOfVerifySignature, response=response)
 
-    @result_as(classname=ResultOfModularPower)
     def modular_power(
-            self, params: ParamsOfModularPower) -> ResultOfModularPower:
+            self, params: ParamsOfModularPower
+    ) -> Union[ResultOfModularPower, Awaitable[ResultOfModularPower]]:
         """
         Performs modular exponentiation for big integers (`base`^`exponent`
         mod `modulus`).
@@ -176,10 +211,12 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfModularPower`
         :return: See `types.ResultOfModularPower`
         """
-        return self.request(method='crypto.modular_power', **params.dict)
+        response = self.request(method='crypto.modular_power', **params.dict)
+        return self.response(classname=ResultOfModularPower, response=response)
 
-    @result_as(classname=ResultOfFactorize)
-    def factorize(self, params: ParamsOfFactorize) -> ResultOfFactorize:
+    def factorize(
+            self, params: ParamsOfFactorize
+    ) -> Union[ResultOfFactorize, Awaitable[ResultOfFactorize]]:
         """
         Performs prime factorization – decomposition of a composite number
         into a product of smaller prime integers (factors).
@@ -188,22 +225,27 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfFactorize`
         :return: See `types.ResultOfFactorize`
         """
-        return self.request(method='crypto.factorize', **params.dict)
+        response = self.request(method='crypto.factorize', **params.dict)
+        return self.response(classname=ResultOfFactorize, response=response)
 
-    @result_as(classname=ResultOfTonCrc16)
-    def ton_crc16(self, params: ParamsOfTonCrc16) -> ResultOfTonCrc16:
+    def ton_crc16(
+            self, params: ParamsOfTonCrc16
+    ) -> Union[ResultOfTonCrc16, Awaitable[ResultOfTonCrc16]]:
         """
         Calculates CRC16 using TON algorithm
 
         :param params: See `types.ParamsOfTonCrc16`
         :return: See `types.ResultOfTonCrc16`
         """
-        return self.request(method='crypto.ton_crc16', **params.dict)
+        response = self.request(method='crypto.ton_crc16', **params.dict)
+        return self.response(classname=ResultOfTonCrc16, response=response)
 
-    @result_as(classname=ResultOfGenerateRandomBytes)
     def generate_random_bytes(
             self, params: ParamsOfGenerateRandomBytes
-    ) -> ResultOfGenerateRandomBytes:
+    ) -> Union[
+        ResultOfGenerateRandomBytes,
+        Awaitable[ResultOfGenerateRandomBytes]
+    ]:
         """
         Generates random byte array of the specified length and returns it
         in `base64` format
@@ -211,24 +253,30 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfGenerateRandomBytes`
         :return: See `types.ResultOfGenerateRandomBytes`
         """
-        return self.request(
+        response = self.request(
             method='crypto.generate_random_bytes', **params.dict)
+        return self.response(
+            classname=ResultOfGenerateRandomBytes, response=response)
 
-    @result_as(classname=ResultOfMnemonicWords)
     def mnemonic_words(
-            self, params: ParamsOfMnemonicWords) -> ResultOfMnemonicWords:
+            self, params: ParamsOfMnemonicWords
+    ) -> Union[ResultOfMnemonicWords, Awaitable[ResultOfMnemonicWords]]:
         """
         Prints the list of words from the specified dictionary
 
         :param params: See `types.ParamsOfMnemonicWords`
         :return: See `types.ResultOfMnemonicWords`
         """
-        return self.request(method='crypto.mnemonic_words', **params.dict)
+        response = self.request(method='crypto.mnemonic_words', **params.dict)
+        return self.response(
+            classname=ResultOfMnemonicWords, response=response)
 
-    @result_as(classname=ResultOfMnemonicFromRandom)
     def mnemonic_from_random(
             self, params: ParamsOfMnemonicFromRandom
-    ) -> ResultOfMnemonicFromRandom:
+    ) -> Union[
+        ResultOfMnemonicFromRandom,
+        Awaitable[ResultOfMnemonicFromRandom]
+    ]:
         """
         Generates a random mnemonic from the specified dictionary
         and word count
@@ -236,25 +284,31 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfMnemonicFromRandom`
         :return: See `types.ResultOfMnemonicFromRandom`
         """
-        return self.request(
+        response = self.request(
             method='crypto.mnemonic_from_random', **params.dict)
+        return self.response(
+            classname=ResultOfMnemonicFromRandom, response=response)
 
-    @result_as(classname=ResultOfMnemonicFromEntropy)
     def mnemonic_from_entropy(
             self, params: ParamsOfMnemonicFromEntropy
-    ) -> ResultOfMnemonicFromEntropy:
+    ) -> Union[
+        ResultOfMnemonicFromEntropy,
+        Awaitable[ResultOfMnemonicFromEntropy]
+    ]:
         """
         Generates mnemonic from pre-generated entropy
 
         :param params: See `types.ParamsOfMnemonicFromEntropy`
         :return: See `types.ResultOfMnemonicFromEntropy`
         """
-        return self.request(
+        response = self.request(
             method='crypto.mnemonic_from_entropy', **params.dict)
+        return self.response(
+            classname=ResultOfMnemonicFromEntropy, response=response)
 
-    @result_as(classname=ResultOfMnemonicVerify)
     def mnemonic_verify(
-            self, params: ParamsOfMnemonicVerify) -> ResultOfMnemonicVerify:
+            self, params: ParamsOfMnemonicVerify
+    ) -> Union[ResultOfMnemonicVerify, Awaitable[ResultOfMnemonicVerify]]:
         """
         The phrase supplied will be checked for word length and validated
         according to the checksum specified in BIP0039
@@ -262,11 +316,13 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfMnemonicVerify`
         :return: See `types.ResultOfMnemonicVerify`
         """
-        return self.request(method='crypto.mnemonic_verify', **params.dict)
+        response = self.request(method='crypto.mnemonic_verify', **params.dict)
+        return self.response(
+            classname=ResultOfMnemonicVerify, response=response)
 
-    @result_as(classname=KeyPair)
     def mnemonic_derive_sign_keys(
-            self, params: ParamsOfMnemonicDeriveSignKeys) -> KeyPair:
+            self, params: ParamsOfMnemonicDeriveSignKeys
+    ) -> Union[KeyPair, Awaitable[KeyPair]]:
         """
         Validates the seed phrase, generates master key and then derives
         the key pair from the master key and the specified path
@@ -274,12 +330,13 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfMnemonicDeriveSignKeys`
         :return: See `types.KeyPair`
         """
-        return self.request(
+        response = self.request(
             method='crypto.mnemonic_derive_sign_keys', **params.dict)
+        return self.response(classname=KeyPair, response=response)
 
-    @result_as(classname=KeyPair)
     def nacl_sign_keypair_from_secret_key(
-            self, params: ParamsOfNaclSignKeyPairFromSecret) -> KeyPair:
+            self, params: ParamsOfNaclSignKeyPairFromSecret
+    ) -> Union[KeyPair, Awaitable[KeyPair]]:
         """
         Generates a key pair for signing from the secret key.
         NOTE: In the result the secret key is actually the concatenation of
@@ -289,22 +346,25 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfNaclSignKeyPairFromSecret`
         :return: See `types.KeyPair`
         """
-        return self.request(
+        response = self.request(
             method='crypto.nacl_sign_keypair_from_secret_key', **params.dict)
+        return self.response(classname=KeyPair, response=response)
 
-    @result_as(classname=ResultOfNaclSign)
-    def nacl_sign(self, params: ParamsOfNaclSign) -> ResultOfNaclSign:
+    def nacl_sign(
+            self, params: ParamsOfNaclSign
+    ) -> Union[ResultOfNaclSign, Awaitable[ResultOfNaclSign]]:
         """
         Signs data using the signer's secret key
 
         :param params: See `types.ParamsOfNaclSign`
         :return: See `types.ResultOfNaclSign`
         """
-        return self.request(method='crypto.nacl_sign', **params.dict)
+        response = self.request(method='crypto.nacl_sign', **params.dict)
+        return self.response(classname=ResultOfNaclSign, response=response)
 
-    @result_as(classname=ResultOfNaclSignDetached)
     def nacl_sign_detached(
-            self, params: ParamsOfNaclSign) -> ResultOfNaclSignDetached:
+            self, params: ParamsOfNaclSign
+    ) -> Union[ResultOfNaclSignDetached, Awaitable[ResultOfNaclSignDetached]]:
         """
         Signs the message using the secret key and returns a signature.
         Signs the message unsigned using the secret key `secret` and returns a
@@ -313,24 +373,31 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfNaclSign`
         :return: See `types.ResultOfNaclSignDetached`
         """
-        return self.request(method='crypto.nacl_sign_detached', **params.dict)
+        response = self.request(
+            method='crypto.nacl_sign_detached', **params.dict)
+        return self.response(
+            classname=ResultOfNaclSignDetached, response=response)
 
-    @result_as(classname=ResultOfNaclSignDetachedVerify)
     def nacl_sign_detached_verify(
             self, params: ParamsOfNaclSignDetachedVerify
-    ) -> ResultOfNaclSignDetachedVerify:
+    ) -> Union[
+        ResultOfNaclSignDetachedVerify,
+        Awaitable[ResultOfNaclSignDetachedVerify]
+    ]:
         """
         Verifies the signature with public key and unsigned data
 
         :param params: See `types.ParamsOfNaclSignDetachedVerify`
         :return: See `types.ResultOfNaclSignDetachedVerify`
         """
-        return self.request(
+        response = self.request(
             method='crypto.nacl_sign_detached_verify', **params.dict)
+        return self.response(
+            classname=ResultOfNaclSignDetachedVerify, response=response)
 
-    @result_as(classname=ResultOfNaclSignOpen)
     def nacl_sign_open(
-            self, params: ParamsOfNaclSignOpen) -> ResultOfNaclSignOpen:
+            self, params: ParamsOfNaclSignOpen
+    ) -> Union[ResultOfNaclSignOpen, Awaitable[ResultOfNaclSignOpen]]:
         """
         Verifies the signature and returns the unsigned message.
         Verifies the signature in `signed` using the signer's public key
@@ -340,27 +407,30 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfNaclSignOpen`
         :return: See `types.ResultOfNaclSignOpen`
         """
-        return self.request(method='crypto.nacl_sign_open', **params.dict)
+        response = self.request(method='crypto.nacl_sign_open', **params.dict)
+        return self.response(classname=ResultOfNaclSignOpen, response=response)
 
-    @result_as(classname=KeyPair)
-    def nacl_box_keypair(self) -> KeyPair:
+    def nacl_box_keypair(self) -> Union[KeyPair, Awaitable[KeyPair]]:
         """ Generates a random NaCl key pair """
-        return self.request(method='crypto.nacl_box_keypair')
+        response = self.request(method='crypto.nacl_box_keypair')
+        return self.response(classname=KeyPair, response=response)
 
-    @result_as(classname=KeyPair)
     def nacl_box_keypair_from_secret_key(
-            self, params: ParamsOfNaclBoxKeyPairFromSecret) -> KeyPair:
+            self, params: ParamsOfNaclBoxKeyPairFromSecret
+    ) -> Union[KeyPair, Awaitable[KeyPair]]:
         """
         Generates key pair from a secret key
 
         :param params: See `types.ParamsOfNaclBoxKeyPairFromSecret`
         :return: See `types.KeyPair`
         """
-        return self.request(
+        response = self.request(
             method='crypto.nacl_box_keypair_from_secret_key', **params.dict)
+        return self.response(classname=KeyPair, response=response)
 
-    @result_as(classname=ResultOfNaclBox)
-    def nacl_box(self, params: ParamsOfNaclBox) -> ResultOfNaclBox:
+    def nacl_box(
+            self, params: ParamsOfNaclBox
+    ) -> Union[ResultOfNaclBox, Awaitable[ResultOfNaclBox]]:
         """
         Public key authenticated encryption.
         Encrypt and authenticate a message using the senders secret key,
@@ -369,11 +439,12 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfNaclBox`
         :return: See `types.ResultOfNaclBox`
         """
-        return self.request(method='crypto.nacl_box', **params.dict)
+        response = self.request(method='crypto.nacl_box', **params.dict)
+        return self.response(classname=ResultOfNaclBox, response=response)
 
-    @result_as(classname=ResultOfNaclBoxOpen)
     def nacl_box_open(
-            self, params: ParamsOfNaclBoxOpen) -> ResultOfNaclBoxOpen:
+            self, params: ParamsOfNaclBoxOpen
+    ) -> Union[ResultOfNaclBoxOpen, Awaitable[ResultOfNaclBoxOpen]]:
         """
         Decrypt and verify the cipher text using the receivers secret key,
         the senders public key, and the nonce
@@ -381,33 +452,37 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfNaclBoxOpen`
         :return: See `types.ResultOfNaclBoxOpen`
         """
-        return self.request(method='crypto.nacl_box_open', **params.dict)
+        response = self.request(method='crypto.nacl_box_open', **params.dict)
+        return self.response(classname=ResultOfNaclBoxOpen, response=response)
 
-    @result_as(classname=ResultOfNaclBox)
     def nacl_secret_box(
-            self, params: ParamsOfNaclSecretBox) -> ResultOfNaclBox:
+            self, params: ParamsOfNaclSecretBox
+    ) -> Union[ResultOfNaclBox, Awaitable[ResultOfNaclBox]]:
         """
         Encrypt and authenticate message using nonce and secret key
 
         :param params: See `types.ParamsOfNaclSecretBox`
         :return: See `types.ResultOfNaclBox`
         """
-        return self.request(method='crypto.nacl_secret_box', **params.dict)
+        response = self.request(method='crypto.nacl_secret_box', **params.dict)
+        return self.response(classname=ResultOfNaclBox, response=response)
 
-    @result_as(classname=ResultOfNaclBoxOpen)
     def nacl_secret_box_open(
-            self, params: ParamsOfNaclSecretBoxOpen) -> ResultOfNaclBoxOpen:
+            self, params: ParamsOfNaclSecretBoxOpen
+    ) -> Union[ResultOfNaclBoxOpen, Awaitable[ResultOfNaclBoxOpen]]:
         """
         Decrypts and verifies cipher text using `nonce` and secret `key`
 
         :param params: See `types.ParamsOfNaclSecretBoxOpen`
         :return: See `types.ResultOfNaclBoxOpen`
         """
-        return self.request(
+        response = self.request(
             method='crypto.nacl_secret_box_open', **params.dict)
+        return self.response(classname=ResultOfNaclBoxOpen, response=response)
 
-    @result_as(classname=ResultOfScrypt)
-    def scrypt(self, params: ParamsOfScrypt) -> ResultOfScrypt:
+    def scrypt(
+            self, params: ParamsOfScrypt
+    ) -> Union[ResultOfScrypt, Awaitable[ResultOfScrypt]]:
         """
         Derives key from `password` and `key` using `scrypt` algorithm.
         See [https://en.wikipedia.org/wiki/Scrypt].
@@ -415,65 +490,80 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfScrypt`
         :return: See `types.ResultOfScrypt`
         """
-        return self.request(method='crypto.scrypt', **params.dict)
+        response = self.request(method='crypto.scrypt', **params.dict)
+        return self.response(classname=ResultOfScrypt, response=response)
 
-    @result_as(classname=ResultOfChaCha20)
-    def chacha20(self, params: ParamsOfChaCha20) -> ResultOfChaCha20:
+    def chacha20(
+            self, params: ParamsOfChaCha20
+    ) -> Union[ResultOfChaCha20, Awaitable[ResultOfChaCha20]]:
         """
         Performs symmetric `chacha20` encryption
 
         :param params: See `types.ParamsOfChaCha20`
         :return: See `types.ResultOfChaCha20`
         """
-        return self.request(method='crypto.chacha20', **params.dict)
+        response = self.request(method='crypto.chacha20', **params.dict)
+        return self.response(classname=ResultOfChaCha20, response=response)
 
-    @result_as(classname=RegisteredSigningBox)
     def register_signing_box(
-            self, callback: ResponseHandler) -> RegisteredSigningBox:
+            self, callback: ResponseHandler
+    ) -> Union[RegisteredSigningBox, Awaitable[RegisteredSigningBox]]:
         """
         Register an application implemented signing box
 
         :param callback: Callback to send events to
         :return: See `types.RegisteredSigningBox`
         """
-        return self.request(
+        response = self.request(
             method='crypto.register_signing_box', callback=callback)
+        return self.response(classname=RegisteredSigningBox, response=response)
 
-    @result_as(classname=RegisteredSigningBox)
-    def get_signing_box(self, params: KeyPair) -> RegisteredSigningBox:
+    def get_signing_box(
+            self, params: KeyPair
+    ) -> Union[RegisteredSigningBox, Awaitable[RegisteredSigningBox]]:
         """
         Creates a default signing box implementation
 
         :param params: See `types.KeyPair`
         :return: See `types.RegisteredSigningBox`
         """
-        return self.request(method='crypto.get_signing_box', **params.dict)
+        response = self.request(method='crypto.get_signing_box', **params.dict)
+        return self.response(classname=RegisteredSigningBox, response=response)
 
-    @result_as(classname=ResultOfSigningBoxGetPublicKey)
     def signing_box_get_public_key(
             self, params: RegisteredSigningBox
-    ) -> ResultOfSigningBoxGetPublicKey:
+    ) -> Union[
+        ResultOfSigningBoxGetPublicKey,
+        Awaitable[ResultOfSigningBoxGetPublicKey]
+    ]:
         """
         Returns public key of signing key pair
 
         :param params: See `types.RegisteredSigningBox`
         :return: See `types.ResultOfSigningBoxGetPublicKey`
         """
-        return self.request(
+        response = self.request(
             method='crypto.signing_box_get_public_key', **params.dict)
+        return self.response(
+            classname=ResultOfSigningBoxGetPublicKey, response=response)
 
-    @result_as(classname=ResultOfSigningBoxSign)
     def signing_box_sign(
-            self, params: ParamsOfSigningBoxSign) -> ResultOfSigningBoxSign:
+            self, params: ParamsOfSigningBoxSign
+    ) -> Union[ResultOfSigningBoxSign, Awaitable[ResultOfSigningBoxSign]]:
         """
         Returns signed user data
 
         :param params: See `types.ParamsOfSigningBoxSign`
         :return: See `types.ResultOfSigningBoxSign`
         """
-        return self.request(method='crypto.signing_box_sign', **params.dict)
+        response = self.request(
+            method='crypto.signing_box_sign', **params.dict)
+        return self.response(
+            classname=ResultOfSigningBoxSign, response=response)
 
-    def remove_signing_box(self, params: RegisteredSigningBox):
+    def remove_signing_box(
+            self, params: RegisteredSigningBox
+    ) -> Union[None, Awaitable[None]]:
         """
         Removes signing box from SDK
 
@@ -482,40 +572,50 @@ class TonCrypto(TonModule):
         """
         return self.request(method='crypto.remove_signing_box', **params.dict)
 
-    @result_as(classname=RegisteredEncryptionBox)
     def register_encryption_box(
-            self, callback: ResponseHandler) -> RegisteredEncryptionBox:
+            self, callback: ResponseHandler
+    ) -> Union[RegisteredEncryptionBox, Awaitable[RegisteredEncryptionBox]]:
         """
         Register an application implemented encryption box
 
         :param callback: Callback to send events to
         :return: See `types.RegisteredEncryptionBox`
         """
-        return self.request(
+        response = self.request(
             method='crypto.register_encryption_box', callback=callback)
+        return self.response(
+            classname=RegisteredEncryptionBox, response=response)
 
-    def remove_encryption_box(self, params: RegisteredEncryptionBox):
+    def remove_encryption_box(
+            self, params: RegisteredEncryptionBox
+    ) -> Union[None, Awaitable[None]]:
         """ Removes encryption box from SDK """
         return self.request(
             method='crypto.remove_encryption_box', **params.dict)
 
-    @result_as(classname=ResultOfEncryptionBoxGetInfo)
     def encryption_box_get_info(
             self, params: ParamsOfEncryptionBoxGetInfo
-    ) -> ResultOfEncryptionBoxGetInfo:
+    ) -> Union[
+        ResultOfEncryptionBoxGetInfo,
+        Awaitable[ResultOfEncryptionBoxGetInfo]
+    ]:
         """
         Queries info from the given encryption box
 
         :param params: See `types.ParamsOfEncryptionBoxGetInfo`
         :return: See `types.ResultOfEncryptionBoxGetInfo`
         """
-        return self.request(
+        response = self.request(
             method='crypto.encryption_box_get_info', **params.dict)
+        return self.response(
+            classname=ResultOfEncryptionBoxGetInfo, response=response)
 
-    @result_as(classname=ResultOfEncryptionBoxEncrypt)
     def encryption_box_encrypt(
             self, params: ParamsOfEncryptionBoxEncrypt
-    ) -> ResultOfEncryptionBoxEncrypt:
+    ) -> Union[
+        ResultOfEncryptionBoxEncrypt,
+        Awaitable[ResultOfEncryptionBoxEncrypt]
+    ]:
         """
         Encrypts data using given encryption box Note.
         Block cipher algorithms pad data to cipher block size so encrypted
@@ -526,13 +626,17 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfEncryptionBoxEncrypt`
         :return: See `types.ResultOfEncryptionBoxEncrypt`
         """
-        return self.request(
+        response = self.request(
             method='crypto.encryption_box_encrypt', **params.dict)
+        return self.response(
+            classname=ResultOfEncryptionBoxEncrypt, response=response)
 
-    @result_as(classname=ResultOfEncryptionBoxDecrypt)
     def encryption_box_decrypt(
             self, params: ParamsOfEncryptionBoxDecrypt
-    ) -> ResultOfEncryptionBoxDecrypt:
+    ) -> Union[
+        ResultOfEncryptionBoxDecrypt,
+        Awaitable[ResultOfEncryptionBoxDecrypt]
+    ]:
         """
         Decrypts data using given encryption box Note.
         Block cipher algorithms pad data to cipher block size so encrypted
@@ -543,18 +647,21 @@ class TonCrypto(TonModule):
         :param params: See `types.ParamsOfEncryptionBoxDecrypt`
         :return: See `types.ResultOfEncryptionBoxDecrypt`
         """
-        return self.request(
+        response = self.request(
             method='crypto.encryption_box_decrypt', **params.dict)
+        return self.response(
+            classname=ResultOfEncryptionBoxDecrypt, response=response)
 
-    @result_as(classname=RegisteredEncryptionBox)
     def create_encryption_box(
             self, params: ParamsOfCreateEncryptionBox
-    ) -> RegisteredEncryptionBox:
+    ) -> Union[RegisteredEncryptionBox, Awaitable[RegisteredEncryptionBox]]:
         """
         Creates encryption box with specified algorithm
 
         :param params: See `types.ParamsOfCreateEncryptionBox`
         :return: See `types.RegisteredEncryptionBox`
         """
-        return self.request(
+        response = self.request(
             method='crypto.create_encryption_box', **params.dict)
+        return self.response(
+            classname=RegisteredEncryptionBox, response=response)
